MathNode

Enum MathNode 

pub enum MathNode<ET: EngineTypes, S: MathFontStyleT<ET>> {
Show 19 variants Atom(MathAtom<ET, S>), Penalty(i32), Mark(usize, TokenList<ET::Token>), Whatsit(WhatsitNode<ET>), HSkip(Skip<ET::Dim>), MSkip { skip: MuSkip<ET::MuDim>, style: S, }, HFil, HFill, HFilneg, Hss, Space, HKern(ET::Dim), MKern { kern: ET::MuDim, style: S, }, Leaders(Leaders<ET>), VRule { width: Option<ET::Dim>, height: Option<ET::Dim>, depth: Option<ET::Dim>, start: SourceRef<ET>, end: SourceRef<ET>, }, Over { start: SourceRef<ET>, end: SourceRef<ET>, top: Box<[MathNode<ET, S>]>, sep: Option<ET::Dim>, bottom: Box<[MathNode<ET, S>]>, left: Option<(ET::Char, S)>, right: Option<(ET::Char, S)>, }, Choice(S::Choice), Marker(S::Markers), Custom(ET::CustomNode),
}
A math list node. Comes in two forms: an unresolved form, while the list is being constructed and the various font styles are not fixed yet (e.g. because an \atop comes later that shifts the font style), and a resolved form, where the fonts have been determined and are fixed. The parameter S:MathFontStyleT makes the distinction between the two forms. For S=MathFontStyle (the resolved form), this implements NodeTrait.

Variants



Atom(MathAtom<ET, S>)

A math atom node (see MathAtom)



Penalty(i32)

A penalty node, as produced by \penalty.



Mark(usize, TokenList<ET::Token>)

A mark node, as produced by \mark.



Whatsit(WhatsitNode<ET>)

A whatsit node, as produced by \special, \write, etc.



HSkip(Skip<ET::Dim>)

A glue node, as produced by \hskip.



MSkip

A glue node, as produced by \mskip. If resolved, S provides the adequate em value.

Fields

skip: MuSkip<ET::MuDim>
style: S


HFil

A glue node, as produced by \hfil.



HFill

A glue node, as produced by \hfill.



HFilneg

A glue node, as produced by \hfilneg.



Hss

A glue node, as produced by \hss.



Space

A glue node, as produced by \



HKern(ET::Dim)

A kern node, as produced by \kern.



MKern

A kern node, as produced by \mkern.

Fields

kern: ET::MuDim
style: S


Leaders(Leaders<ET>)

A leaders node, as produced by \leaders or \cleaders or \xleaders.



VRule

A rule node, as produced by \vrule.

Fields

width: Option<ET::Dim>

The provided width of the rule.

height: Option<ET::Dim>

The provided height of the rule.

depth: Option<ET::Dim>

The provided depth of the rule.

start: SourceRef<ET>

The source reference for the start of the rule.

end: SourceRef<ET>

The source reference for the end of the rule.



Over

A “generalized fraction”, as produced by \over, \atop, \above, \abovewithdelims, \overwithdelims, \atopwithdelims.

Fields

start: SourceRef<ET>

The source reference for the start of the node.

end: SourceRef<ET>

The source reference for the end of the node.

top: Box<[MathNode<ET, S>]>

The numerator.

sep: Option<ET::Dim>

The optional separator height.

bottom: Box<[MathNode<ET, S>]>

The denominator.

left: Option<(ET::Char, S)>

The optional left delimiter.

right: Option<(ET::Char, S)>

The optional right delimiter.



Choice(S::Choice)

A \mathchoice node; if resolved, this is just a wrapper around more math nodes.



Marker(S::Markers)

Markers for the various font styles, e.g. \displaystyle, \textstyle, etc.



Custom(ET::CustomNode)

A custom node.

Implementations

Source

impl<ET: EngineTypes> MathNode<ET, UnresolvedMathFontStyle<ET>>

pub fn nodetype(&self) -> NodeType

The node type of this node (as in \lastnodetype).

pub fn opaque(&self) -> bool