pub enum MathNucleus<ET: EngineTypes, S: MathFontStyleT<ET>> {
Simple {
cls: MathClass,
kernel: MathKernel<ET, S>,
limits: Option<bool>,
},
Inner(MathKernel<ET, S>),
LeftRight {
start: SourceRef<ET>,
left: Option<(ET::Char, S)>,
children: Box<[MathNode<ET, S>]>,
right: Option<(ET::Char, S)>,
end: SourceRef<ET>,
},
Middle(ET::Char, S),
Overline(MathKernel<ET, S>),
Underline(MathKernel<ET, S>),
Accent {
accent: (ET::Char, S),
inner: Box<[MathNode<ET, S>]>,
},
Radical {
rad: (ET::Char, S),
inner: Box<[MathNode<ET, S>]>,
},
VCenter {
start: SourceRef<ET>,
end: SourceRef<ET>,
children: Box<[VNode<ET>]>,
scaled: ToOrSpread<ET::Dim>,
},
}Expand description
The nucleus of a MathAtom; a cohesive “unit” with optional sub/superscript.
Variants
Simple
A simple nucleus, consisting of a MathKernel and a math class.
limits is None during construction of the list, and Some(true) or Some(false)
after the list has been closed, or if a large operator is followed by a \limits or \nolimits.
Inner(MathKernel<ET, S>)
A \mathinner node, as produced by {...}
LeftRight
A node produced by \left...\right.
Fields
Middle(ET::Char, S)
A node produced by \middle.
Overline(MathKernel<ET, S>)
A node produced by \overline.
Underline(MathKernel<ET, S>)
A node produced by \underline.
Accent
A node produced by \mathaccent.
Radical
A node produced by \radical.
VCenter
A node produced by \vcenter.