UnresolvedMarkers

Enum UnresolvedMarkers 

pub enum UnresolvedMarkers {
    Display,
    Text,
    Script,
    ScriptScript,
}
Markers inserted by \displaystyle, \textstyle, \scriptstyle and \scriptscriptstyle. Only meaningful in unresolved mode, while the math list is open. When the list is closed, these are removed and used to determine the font style at that point.

Variants



Display



Text



Script



ScriptScript