pub struct MathAtom<ET: EngineTypes, S: MathFontStyleT<ET>> {
pub nucleus: MathNucleus<ET, S>,
pub sup: Option<Box<[MathNode<ET, S>]>>,
pub sub: Option<Box<[MathNode<ET, S>]>>,
}Expand description
The most central kind of node in a math list. Consisting of a nucleus with optional superscript and subscript math lists.
Fields
nucleus: MathNucleus<ET, S>sup: Option<Box<[MathNode<ET, S>]>>sub: Option<Box<[MathNode<ET, S>]>>Implementations
Sourceimpl<ET: EngineTypes, S: MathFontStyleT<ET>> MathAtom<ET, S>
impl<ET: EngineTypes, S: MathFontStyleT<ET>> MathAtom<ET, S>