pub struct MathGroup<ET: EngineTypes> {
pub display: Option<(Skip<ET::Dim>, Skip<ET::Dim>)>,
pub children: Box<[MathNode<ET, MathFontStyle<ET>>]>,
pub start: SourceRef<ET>,
pub end: SourceRef<ET>,
pub eqno: Option<(EqNoPosition, Box<[MathNode<ET, MathFontStyle<ET>>]>)>,
pub computed_width: OnceCell<ET::Dim>,
pub computed_height: OnceCell<ET::Dim>,
pub computed_depth: OnceCell<ET::Dim>,
}Expand description
A resolved math group; the result of a math list.
Fields
display: Option<(Skip<ET::Dim>, Skip<ET::Dim>)>If this is a display math group, the \abovedisplayskip and \belowdisplayskip
values.
children: Box<[MathNode<ET, MathFontStyle<ET>>]>The nodes in this group
start: SourceRef<ET>The source reference of the $ or $$ that started this group.
end: SourceRef<ET>The source reference of the $ or $$ that ended this group.
eqno: Option<(EqNoPosition, Box<[MathNode<ET, MathFontStyle<ET>>]>)>If the mathgroup contained an \eqno or \leqno,
the nodes following that command
computed_width: OnceCell<ET::Dim>The computed width of this group - i.e. the sum of the widths of the children.
computed_height: OnceCell<ET::Dim>The computed height of this group - i.e. the maximum of the heights of the children.
computed_depth: OnceCell<ET::Dim>The computed depth of this group - i.e. the maximum of the depths of the children.
Implementations
Sourceimpl<ET: EngineTypes> MathGroup<ET>
impl<ET: EngineTypes> MathGroup<ET>
Sourcepub fn close(
state: &ET::State,
display: Option<(Skip<ET::Dim>, Skip<ET::Dim>)>,
start: SourceRef<ET>,
end: SourceRef<ET>,
children: Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>,
eqno: Option<(EqNoPosition, Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>)>,
) -> Self
pub fn close( state: &ET::State, display: Option<(Skip<ET::Dim>, Skip<ET::Dim>)>, start: SourceRef<ET>, end: SourceRef<ET>, children: Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>, eqno: Option<(EqNoPosition, Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>)>, ) -> Self
Create a new math group by closing a list of unresolved math nodes, iterating
over it and resolving each node by determining the appropriate MathFontStyle for
it.
If display is Some, this is a display math group, and the two
skips are the \abovedisplayskip and \belowdisplayskip values.