pub struct ResolvedChoice<ET: EngineTypes>(pub Box<[MathNode<ET, MathFontStyle<ET>>]>);Expand description
A resolved \mathchoice node. This is the state after the math list has been constructed,
at which point it is only a wrapper around a list of nodes.
Tuple Fields
0: Box<[MathNode<ET, MathFontStyle<ET>>]>Implementations
Sourceimpl<ET: EngineTypes> ResolvedChoice<ET>
impl<ET: EngineTypes> ResolvedChoice<ET>