UnresolvedMathFontStyle

Struct UnresolvedMathFontStyle 

pub struct UnresolvedMathFontStyle<ET: EngineTypes>(/* private fields */);
Unresolved math font style. This is the state while the math list is being constructed. Carries information about the family if relevant (or 0), to be picked when the math list is resolved.

Implementations

Source

impl<ET: EngineTypes> UnresolvedMathFontStyle<ET>

pub fn of_fam(fam: u8) -> Self

Create a new unresolved math font style with the given family.

pub fn fam(&self) -> u8

The family to use.