MathChoiceT

Trait MathChoiceT 

pub trait MathChoiceT<ET: EngineTypes>: Clone + Debug { }
This trait is implemented for exactly two types that indicate whether we are in the unresolved UnresolvedMathFontStyle or resolved (MathFontStyle) state.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors