pub enum MathNodeList<ET: EngineTypes> {
Simple(Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>),
Over {
top: Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>,
sep: Option<ET::Dim>,
bottom: Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>,
left: Option<(ET::Char, UnresolvedMathFontStyle<ET>)>,
right: Option<(ET::Char, UnresolvedMathFontStyle<ET>)>,
},
EqNo {
pos: EqNoPosition,
main: Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>,
eqno: Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>,
},
}Expand description
An open list of unresolved math nodes. TODO: rethink this
Variants
Simple(Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>)
A simple list of nodes
Over
An open list after encountering an \over or \above or \atop or
a related command. The current list up to that point is moved to the top,
subsequent nodes are added to bottom. (see MathNode::Over
Fields

top: Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>
bottom: Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>
left: Option<(ET::Char, UnresolvedMathFontStyle<ET>)>
right: Option<(ET::Char, UnresolvedMathFontStyle<ET>)>EqNo
An open list after encountering an \eqno or \leqno.
The current list up to that point is moved to main,
subsequent nodes are added to eqno. This can
only happen, if this list’s direct “parent” is a horizontal
(i.e. non-math) list.
Fields

pos: EqNoPosition
main: Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>
eqno: Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>Implementations
Sourceimpl<ET: EngineTypes> MathNodeList<ET>
impl<ET: EngineTypes> MathNodeList<ET>
Sourcepub fn push(&mut self, n: MathNode<ET, UnresolvedMathFontStyle<ET>>)
pub fn push(&mut self, n: MathNode<ET, UnresolvedMathFontStyle<ET>>)
Push a node to the list.
Sourcepub fn close(
self,
start: SourceRef<ET>,
end: SourceRef<ET>,
) -> (Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>, Option<(EqNoPosition, Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>)>)
pub fn close( self, start: SourceRef<ET>, end: SourceRef<ET>, ) -> (Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>, Option<(EqNoPosition, Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>)>)
Close the list, returning the list of nodes and the optional eqno.
Sourcepub fn list_mut(
&mut self,
) -> &mut Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>
pub fn list_mut( &mut self, ) -> &mut Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>
Get the “open” list that nodes should be added to mutably
Sourcepub fn list(&self) -> &Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>
pub fn list(&self) -> &Vec<MathNode<ET, UnresolvedMathFontStyle<ET>>>
Get the “open” list that nodes should be added to immutably