pub struct UnresolvedMathFontStyle<ET: EngineTypes>(/* private fields */);Expand description
Unresolved math font style. This is the state while the math list is being constructed. Carries information about the family if relevant (or 0), to be picked when the math list is resolved.
Implementations
Sourceimpl<ET: EngineTypes> UnresolvedMathFontStyle<ET>
impl<ET: EngineTypes> UnresolvedMathFontStyle<ET>