MathFontStyleT

Trait MathFontStyleT 

pub trait MathFontStyleT<ET: EngineTypes>: Clone + Debug {
    type Choice: MathChoiceT<ET>;
    type Markers: Clone + Debug + NodeTrait<ET>;
}
This trait is implemented for exactly two types that indicate whether we are in the unresolved UnresolvedMathFontStyle or resolved (MathFontStyle) state.

Required Associated Types

type Choice: MathChoiceT<ET>

The type of the choice node, which is either UnresolvedMathChoice or ResolvedChoice.

type Markers: Clone + Debug + NodeTrait<ET>

The type of the markers, which is either UnresolvedMarkers or a dummy that never occurs.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors