pub trait MathFontStyleT<ET: EngineTypes>: Clone + Debug {
type Choice: MathChoiceT<ET>;
type Markers: Clone + Debug + NodeTrait<ET>;
}Expand description
This trait is implemented for exactly two types that indicate
whether we are in the unresolved UnresolvedMathFontStyle or resolved
(MathFontStyle) state.
Required Associated Types
Sourcetype Choice: MathChoiceT<ET>
type Choice: MathChoiceT<ET>
The type of the choice node, which is either UnresolvedMathChoice or ResolvedChoice.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.